import pytest
from geomfig import Triangle

def test_triangle_area():
    t = Triangle(6, 7, 3)
    assert abs(t.area() - 8.94427190999916) < 1e-7

#Проверка на прямоугольный  треугольник
def test_right_angle_triangle_area():
    t = Triangle(3, 4, 5)
    assert abs(t.area()-6) < 1e-7

#Проверка на отрицательную сторону
def test_triangle_negative_side():
    with pytest.raises(ValueError):
        Triangle(8, -2, 9)

#Проверка на нулевую сторону
def test_triangle_zero_side():
    with pytest.raises(ValueError):
        Triangle(3, 2, 0)

#Проверка неравнества треугольника
def test_triangle_inequality():
    with pytest.raises(ValueError):
        Triangle(3, 8, 14)


import pytest
from geomfig import Circle

def test_circle_area():
    c = Circle(9)
    assert abs(c.area() - 254.46900494077323) < 1e-7

def test_circle_negative_radius():
    with pytest.raises(ValueError):
        Circle(-1)

def test_circle_zero_radius():
    with pytest.raises(ValueError):
        Circle(0)


from math import sqrt
from .base import Figure

class Triangle(Figure):
    def __init__(self, s1: float, s2: float, s3: float):
        if s1 <= 0 or s2 <= 0 or s3 <= 0:
            raise ValueError("All sides must be positive")
        # Проверка неравенства треугольника
        if s1 + s2 <= s3 or s1 + s3 <= s2 or s2 + s3 <= s1:
            raise ValueError("Invalid triangle sides")
        self.s1, self.s2, self.s3 = s1, s2, s3

    def area(self) -> float:
        ls = sorted([self.s1, self.s2, self.s3], reverse=False)
        #проверка на прямоугольный треугольник
        if (abs(ls[0]**2+ls[1]**2-ls[2]**2) < 1e-7):
            return (ls[0]*ls[1])/2
        else:# Формула Герона
            p = (self.s1 + self.s2 + self.s3)/2
            return sqrt(p*(p-self.s1)*(p-self.s2)*(p-self.s3))



from math import pi
from .base import Figure

class Circle(Figure):
    def __init__(self, radius: float):
        if radius <= 0:
            raise ValueError("Radius must be positive")
        self.radius = radius

    def area(self) -> float:
        return pi*self.radius**2


from geomfig import Circle, Triangle, Figure

def compute_total_area(figure: list[Figure]):
    return sum([fig.area() for fig in figure])

def test_polymorphism():
    ls_fig = [Circle(3), Triangle(3, 4, 5)]
    assert abs(compute_total_area(ls_fig) - 34.27433388230814) < 1e-7